==> react-image-annotate_ns_demo-5.0.27.tgz: package/OCR/FormOCR.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import { Typography } from "@mui/material";
import React from "react";
import AnnotationInput from "../Components/AnnotationInput";

function FormOCR(_ref) {
  var index = _ref.index,
      formData = _ref.formData,
      setFormData = _ref.setFormData,
      item = _ref.item;

  var _ref2 = item || {},
      invalid = _ref2.invalid,
      description_labelling = _ref2.description_labelling,
      image_urls_labelling = _ref2.image_urls_labelling,
      title = _ref2.title,
      default_type = _ref2.default_type,
      display_label = _ref2.display_label,
      content = _ref2.content,
      input_type = _ref2.input_type,
      value = _ref2.value,
      other_value = _ref2.other_value,
      mandatory = _ref2.mandatory,
      history_hide = _ref2.history_hide;

  return input_type === "label" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("p", {
    className: "font-MontSemiBold task_formlabel"
  }, display_label), /*#__PURE__*/React.createElement(Typography, null, content)) : input_type === "textArea" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("label", {
    className: "task_formlabel",
    htmlFor: display_label
  }, display_label), /*#__PURE__*/React.createElement(AnnotationInput, {
    isRequired: mandatory === "mandatory",
    rows: 3 // title={value.name}
    ,
    id: display_label,
    value: content,
    fullWidth: true,
    onChange: function onChange(e) {
      var data = _toConsumableArray(formData);

      data[index].content = e.target.value;
      setFormData(data);
    },
    focused: true
  })) : null;
}

export default FormOCR;

==> react-image-annotate_ns_demo-5.0.30.tgz: package/OCR/FormOCR.js <==
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import { Typography } from "@mui/material";
import React from "react";
import AnnotationInput from "../Components/AnnotationInput";

function FormOCR(_ref) {
  var index = _ref.index,
      formData = _ref.formData,
      setFormData = _ref.setFormData,
      item = _ref.item;

  var _ref2 = item || {},
      invalid = _ref2.invalid,
      description_labelling = _ref2.description_labelling,
      image_urls_labelling = _ref2.image_urls_labelling,
      title = _ref2.title,
      default_type = _ref2.default_type,
      display_label = _ref2.display_label,
      content = _ref2.content,
      input_type = _ref2.input_type,
      value = _ref2.value,
      other_value = _ref2.other_value,
      mandatory = _ref2.mandatory,
      history_hide = _ref2.history_hide;

  var labelStyle = {
    whiteSpace: "nowrap",
    width: "90%",
    overflow: "hidden",
    textOverflow: "ellipsis",
    display: "inline-block"
  };
  return input_type === "label" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("p", {
    className: "font-MontSemiBold task_formlabel"
  }, display_label), /*#__PURE__*/React.createElement(Typography, null, content)) : input_type === "textArea" ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("label", {
    className: "task_formlabel",
    htmlFor: display_label,
    style: _objectSpread({}, labelStyle),
    title: display_label
  }, display_label), /*#__PURE__*/React.createElement(AnnotationInput, {
    isRequired: mandatory === "mandatory",
    rows: 3 // title={value.name}
    ,
    id: display_label,
    value: content,
    fullWidth: true,
    onChange: function onChange(e) {
      var data = _toConsumableArray(formData);

      data[index].content = e.target.value;
      setFormData(data);
    },
    focused: true
  })) : null;
}

export default FormOCR;
